@@ -4,7 +4,7 @@ mod reporter;
 mod snapshot;
 mod test_case;
 
-use crate::config::{find_rules, register_custom_language};
+use crate::config::ProjectConfig;
 use crate::lang::SgLang;
 use crate::utils::ErrorContext;
 use anyhow::{anyhow, Result};
@@ -56,8 +56,12 @@ where
   })
 }
 
-fn run_test_rule_impl<R: Reporter + Send>(arg: TestArg, reporter: R) -> Result<()> {
-  let collections = &find_rules(arg.config.clone(), None)?.0;
+fn run_test_rule_impl<R: Reporter + Send>(
+  arg: TestArg,
+  reporter: R,
+  project: ProjectConfig,
+) -> Result<()> {
+  let collections = &project.find_rules(Default::default())?.0;
   let TestHarness {
     test_cases,
     snapshots,
@@ -66,7 +70,7 @@ fn run_test_rule_impl<R: Reporter + Send>(arg: TestArg, reporter: R) -> Result<(
     let snapshot_dirname = arg.snapshot_dir.as_deref();
     TestHarness::from_dir(&test_dirname, snapshot_dirname, arg.filter.as_ref())?
   } else {
-    TestHarness::from_config(arg.config, arg.filter.as_ref())?
+    TestHarness::from_config(project, arg.filter.as_ref())?
   };
   let snapshots = (!arg.skip_snapshot_tests).then_some(snapshots);
   let reporter = &Arc::new(Mutex::new(reporter));
@@ -156,9 +160,6 @@ fn verify_test_case_simple<'a>(
 
 #[derive(Args)]
 pub struct TestArg {
-  /// Path to the root ast-grep config YAML
-  #[clap(short, long)]
-  config: Option<PathBuf>,
   /// the directories to search test YAML files
   #[clap(short, long)]
   test_dir: Option<PathBuf>,
@@ -182,20 +183,20 @@ pub struct TestArg {
   filter: Option<Regex>,
 }
 
-pub fn run_test_rule(arg: TestArg) -> Result<()> {
-  register_custom_language(arg.config.clone())?;
+pub fn run_test_rule(arg: TestArg, project: Result<ProjectConfig>) -> Result<()> {
+  let project = project?;
   if arg.interactive {
     let reporter = InteractiveReporter {
       output: std::io::stdout(),
       should_accept_all: false,
     };
-    run_test_rule_impl(arg, reporter)
+    run_test_rule_impl(arg, reporter, project)
   } else {
     let reporter = DefaultReporter {
       output: std::io::stdout(),
       update_all: arg.update_all,
     };
-    run_test_rule_impl(arg, reporter)
+    run_test_rule_impl(arg, reporter, project)
   }
 }
 
@@ -300,15 +301,9 @@ rule:
     assert!(ret.is_none());
   }
 
-  use codespan_reporting::term::termcolor::Buffer;
   #[test]
   fn test_run_verify_error() {
-    let reporter = DefaultReporter {
-      output: Buffer::no_color(),
-      update_all: false,
-    };
     let arg = TestArg {
-      config: None,
       interactive: false,
       skip_snapshot_tests: true,
       snapshot_dir: None,
@@ -316,7 +311,7 @@ rule:
       update_all: false,
       filter: None,
     };
-    assert!(run_test_rule_impl(arg, reporter).is_err());
+    assert!(run_test_rule(arg, Err(anyhow!("error"))).is_err());
   }
   const TRANSFORM_TEXT: &str = "
 transform:
