@@ -1,13 +1,18 @@
 import test from 'ava'
 
 import {
-  js, ts, tsx, html, Lang,
-  parseFiles, parseAsync, findInFiles,
+  js,
+  ts,
+  tsx,
+  html,
+  Lang,
+  parseFiles,
+  parseAsync,
+  findInFiles,
   parse as parseWithLang,
 } from '../index'
 const { parse, kind } = js
-let parseMulti = countedPromise(parseFiles)
-
+const parseMulti = countedPromise(parseFiles)
 
 test('find from native code', t => {
   const sg = parse('console.log(123)')
@@ -45,8 +50,8 @@ test('find multiple nodes', t => {
     end: { line: 0, column: 10, index: 10 },
   })
   const matchedVar = match!.getMultipleMatches('B')
-  let start = matchedVar[0].range().start;
-  let end = matchedVar[matchedVar.length - 1].range().end;
+  const start = matchedVar[0].range().start
+  const end = matchedVar[matchedVar.length - 1].range().end
   t.deepEqual(start, { line: 0, column: 2, index: 2 })
   t.deepEqual(end, { line: 0, column: 9, index: 9 })
 })
@@ -80,15 +85,14 @@ test('find with transformation', t => {
           source: '$A',
           startChar: 1,
           endChar: -1,
-        }
+        },
       },
-    }
+    },
   })!
   t.deepEqual(match.getTransformed('NEW_ARG'), 'Hello, 世界')
   t.deepEqual(match.getMatch('A')?.text(), '"Hello, 世界"')
 })
 
-
 test('test code fix', t => {
   const sg = parse('a = console.log(123)')
   const match = sg.root().find('console.log')!
@@ -160,7 +164,7 @@ test('find by kind', t => {
 test('find by config', t => {
   const sg = parse('console.log("hello world")')
   const match = sg.root().find({
-    rule: {kind: 'member_expression'},
+    rule: { kind: 'member_expression' },
   })
   t.deepEqual(match!.range(), {
     start: { line: 0, column: 0, index: 0 },
@@ -178,10 +182,10 @@ test('test find files', async t => {
 
 test('test file count', async t => {
   let i = 0
-  let fileCount = await parseMulti(['./'], (err, _) => {
+  const fileCount = await parseMulti(['./'], (err, _) => {
     // ZZZ... sleep a while to mock expensive operation
-    let start = Date.now()
-    while (Date.now() - start < 1) continue
+    const start = Date.now()
+    while (Date.now() - start < 1) {}
     t.is(err, null)
     i++
   })
@@ -191,32 +195,39 @@ test('test file count', async t => {
 test('test languageGlobs', async t => {
   let i = 0
   let foundVue = false
-  let fileCount = await parseMulti({
-    paths: ['./'],
-    languageGlobs: {
-      'html': ['*.vue']
+  const fileCount = await parseMulti(
+    {
+      paths: ['./'],
+      languageGlobs: {
+        html: ['*.vue'],
+      },
     },
-  }, (err, root) => {
-    t.is(err, null)
-    if (root.filename().endsWith('.vue')) {
-      foundVue = true
-    }
-    i++
-  })
+    (err, root) => {
+      t.is(err, null)
+      if (root.filename().endsWith('.vue')) {
+        foundVue = true
+      }
+      i++
+    },
+  )
   t.is(i, fileCount)
   t.true(foundVue)
 })
 
 test('show good error message for invalid arg', async t => {
   const sg = parse('console.log(123)')
-  t.throws(() => sg.root().find({rule: {regex: '('}}), {
-    message: /Rule contains invalid regex matcher/
-  })
-  t.throws(() => sg.root().find({
-    rule: { all: [{any: [{ kind: '33'}]}]}
-  }), {
-    message: /Rule contains invalid kind matcher/
+  t.throws(() => sg.root().find({ rule: { regex: '(' } }), {
+    message: /Rule contains invalid regex matcher/,
   })
+  t.throws(
+    () =>
+      sg.root().find({
+        rule: { all: [{ any: [{ kind: '33' }] }] },
+      }),
+    {
+      message: /Rule contains invalid kind matcher/,
+    },
+  )
 })
 
 test('get node id', async t => {
@@ -227,115 +238,147 @@ test('get node id', async t => {
 })
 
 test('find in files', async t => {
-  let findInFiles = countedPromise(ts.findInFiles)
-  await findInFiles({
-    paths: ['./'],
-    matcher: {
-      rule: {kind: 'member_expression'}
+  const findInFiles = countedPromise(ts.findInFiles)
+  await findInFiles(
+    {
+      paths: ['./'],
+      matcher: {
+        rule: { kind: 'member_expression' },
+      },
     },
-  }, (err, n) => {
-    // ZZZ... sleep a while to mock expensive operation
-    let start = Date.now()
-    while (Date.now() - start < 1) continue
-    t.is(err, null)
-    t.assert(n.length > 0)
-    t.assert(n[0].text().includes('.'))
-  })
+    (err, n) => {
+      // ZZZ... sleep a while to mock expensive operation
+      const start = Date.now()
+      while (Date.now() - start < 1) {}
+      t.is(err, null)
+      t.assert(n.length > 0)
+      t.assert(n[0].text().includes('.'))
+    },
+  )
 })
 
 // gh #1380
 test('find in files with meta var', async t => {
-  let findInFiles = countedPromise(ts.findInFiles)
-  await findInFiles({
-    paths: ['./'],
-    matcher: {
-      rule: {pattern: 'parse($V)'}
+  const findInFiles = countedPromise(ts.findInFiles)
+  await findInFiles(
+    {
+      paths: ['./'],
+      matcher: {
+        rule: { pattern: 'parse($V)' },
+      },
     },
-  }, (err, n) => {
-    // ZZZ... sleep a while to mock expensive operation
-    let start = Date.now()
-    while (Date.now() - start < 1) continue
-    t.is(err, null)
-    t.assert(n.length > 0)
-    const metavarText = n[0].getMatch('V')?.text()
-    t.is(metavarText, "'console.log(123)'")
-  })
+    (err, n) => {
+      // ZZZ... sleep a while to mock expensive operation
+      const start = Date.now()
+      while (Date.now() - start < 1) {}
+      t.is(err, null)
+      t.assert(n.length > 0)
+      const metavarText = n[0].getMatch('V')?.text()
+      t.is(metavarText, "'console.log(123)'")
+    },
+  )
 })
 
 test('find in files with filename', async t => {
-  let findInFiles = countedPromise(ts.findInFiles)
-  await findInFiles({
-    paths: ['./'],
-    matcher: {
-      rule: {kind: 'await_expression'},
+  const findInFiles = countedPromise(ts.findInFiles)
+  await findInFiles(
+    {
+      paths: ['./__test__/'],
+      matcher: {
+        rule: { kind: 'await_expression' },
+      },
     },
-  }, (err, n) => {
-    t.is(err, null)
-    const root = n[0].getRoot();
-    t.assert(root.filename().includes('index.spec.ts'))
-  })
+    (err, n) => {
+      t.is(err, null)
+      const root = n[0].getRoot()
+      const filename = root.filename()
+      t.assert(filename.includes('.spec.ts'))
+    },
+  )
 })
 
 test('tsx should not find ts file', async t => {
-  await tsx.findInFiles({
-    paths: ['./'],
-    matcher: {
-      rule: {kind: 'member_expression'},
+  await tsx.findInFiles(
+    {
+      paths: ['./'],
+      matcher: {
+        rule: { kind: 'member_expression' },
+      },
     },
-  }, () => {
-    t.assert(false)
-  })
+    () => {
+      t.assert(false)
+    },
+  )
   t.assert(true)
 })
 
 test('find with language globs', async t => {
-  let findInFiles = countedPromise(tsx.findInFiles)
-  await findInFiles({
-    paths: ['./'],
-    matcher: {
-      rule: {kind: 'await_expression'},
+  const findInFiles = countedPromise(tsx.findInFiles)
+  await findInFiles(
+    {
+      paths: ['./__test__/'],
+      matcher: {
+        rule: { kind: 'await_expression' },
+      },
+      languageGlobs: ['*.ts'],
     },
-    languageGlobs: ['*.ts'],
-  }, (err, n) => {
-    t.is(err, null)
-    const root = n[0].getRoot();
-    t.assert(root.filename().includes('index.spec.ts'))
-  })
+    (err, n) => {
+      t.is(err, null)
+      const root = n[0].getRoot()
+      t.assert(root.filename().includes('.spec.ts'))
+    },
+  )
 })
 
 test('find with language globs can parse with correct language', async t => {
-  let findInFiles = countedPromise(html.findInFiles)
-  await findInFiles({
-    paths: ['./'],
-    matcher: {
-      rule: {pattern: '<template>$A</template>'},
+  const findInFiles = countedPromise(html.findInFiles)
+  await findInFiles(
+    {
+      paths: ['./'],
+      matcher: {
+        rule: { pattern: '<template>$A</template>' },
+      },
+      languageGlobs: ['*.vue'],
     },
-    languageGlobs: ['*.vue'],
-  }, (err, n) => {
-    t.is(err, null)
-    const root = n[0].getRoot();
-    t.is(root.filename().replace('\\', '/'), './__test__/test.vue')
-    const div = root.root().find('<h1>$A</h1>')?.getMatch('A')?.text()
-    t.is(div, '{{ greeting }}')
-  })
+    (err, n) => {
+      t.is(err, null)
+      const root = n[0].getRoot()
+      t.is(root.filename().replace('\\', '/'), './__test__/test.vue')
+      const div = root.root().find('<h1>$A</h1>')?.getMatch('A')?.text()
+      t.is(div, '{{ greeting }}')
+    },
+  )
 })
 
+test('fieldChildren returns all the fields of the given field', t => {
+  const sg = tsx.parse('const el = <div id="foo" className="bar" />')
+  const jsxElement = sg.root().find(tsx.kind('jsx_self_closing_element'))!
+  const fields = jsxElement.fieldChildren('attribute')
+  t.is(fields.length, 2)
+  t.is(fields[0].text(), 'id="foo"')
+  t.is(fields[1].text(), 'className="bar"')
+})
 
-function countedPromise<F extends (t: any, cb: any) => Promise<number>>(func: F) {
+// biome-ignore lint/suspicious/noExplicitAny: do not complain any
+function countedPromise<F extends (t: any, cb: any) => Promise<number>>(
+  func: F,
+) {
   type P = Parameters<F>
   return async (t: P[0], cb: P[1]) => {
     let i = 0
     let fileCount: number | undefined = undefined
     let resolve = () => {} // will be called after all files are processed
-    function wrapped(...args: any[]) {
-      let ret = cb(...args)
+    function wrapped(...args: unknown[]) {
+      const ret = cb(...args)
       if (++i === fileCount) resolve()
       return ret
     }
     fileCount = await func(t, wrapped as P[1])
     // all files are not processed, wait the resolve function to be called
     if (fileCount > i) {
-      await new Promise<void>(r => resolve = r)
+      await new Promise<void>(r => {
+        resolve = r
+      })
     }
     return fileCount
   }
@@ -362,28 +405,33 @@ test('parse python async', async t => {
 test('find rust', async t => {
   let changed = false
   const counted = countedPromise((t, cb) => findInFiles(Lang.Rust, t, cb))
-  const num = await counted({
-    paths: ['./'],
-    matcher: {
-      rule: {pattern: 'ast_grep_core'},
+  const num = await counted(
+    {
+      paths: ['./'],
+      matcher: {
+        rule: { pattern: 'ast_grep_core' },
+      },
     },
-  }, () => {
-    changed = true
-  })
+    () => {
+      changed = true
+    },
+  )
   t.assert(changed)
   t.assert(num > 0)
 })
 
-test("find node by range", (t) => {
-  const sg = parse("const message = `This is a multiline message with unicode characters\nÜbergang\nدرود\n🙌\n`;")
+test('find node by range', t => {
+  const sg = parse(
+    'const message = `This is a multiline message with unicode characters\nÜbergang\nدرود\n🙌\n`;',
+  )
   const node = sg.root().find({
     rule: {
       range: {
-        start: { row: 0, column: 16 },
-        end: { row: 4, column: 1 },
-      }
-    }
+        start: { line: 0, column: 16 },
+        end: { line: 4, column: 1 },
+      },
+    },
   })
-  const byKind = sg.root().find(js.kind("template_string"))
+  const byKind = sg.root().find(js.kind('template_string'))
   t.is(node!.id(), byKind!.id())
 })
